==> purchaser-invoice-manage-saas-domain-0.0.221-sources.jar: com/xforceplus/ultraman/app/purchaserinvoicemanagesaas/metadata/FormMeta.java <==
package com.xforceplus.ultraman.app.purchaserinvoicemanagesaas.metadata;

/**
 *
 * @author ultraman
 * @since 2024-11-01
 */

public class FormMeta {
    public interface BusinessField {
        static String code() {
            return "businessField";
        }
        static String name() {
            return "业务字段变更表单";
        }
    }
    public interface AddRiskInvoice {
        static String code() {
            return "addRiskInvoice";
        }
        static String name() {
            return "新增风险发票";
        }
    }
    public interface RiskInvoiceFollow {
        static String code() {
            return "riskInvoiceFollow";
        }
        static String name() {
            return "风险发票跟进";
        }
    }
    public interface VankeRiskInvoice {
        static String code() {
            return "vankeRiskInvoice";
        }
        static String name() {
            return "万科风险发票详情";
        }
    }
    public interface BizOrderDetailForm {
        static String code() {
            return "bizOrderDetailForm";
        }
        static String name() {
            return "发票池业务单详情";
        }
    }
    public interface DeleteImgDetail {
        static String code() {
            return "deleteImgDetail";
        }
        static String name() {
            return "已删除影像详情";
        }
    }
    public interface InvoicePoolButtonForm {
        static String code() {
            return "invoicePoolButtonForm";
        }
        static String name() {
            return "发票池 按钮 弹框表单";
        }
    }
    public interface InvoiceEntryStatusForm {
        static String code() {
            return "invoiceEntryStatusForm";
        }
        static String name() {
            return "发票入账调整入账未入账状态表单";
        }
    }
    public interface InvoiceEntryForm {
        static String code() {
            return "invoiceEntryForm";
        }
        static String name() {
            return "发票入账调整入账已入账、入账失败状态表单";
        }
    }
    public interface DownloadFile {
        static String code() {
            return "downloadFile";
        }
        static String name() {
            return "下载影像/文件";
        }
    }
}

==> purchaser-invoice-manage-saas-domain-0.0.343-sources.jar: com/xforceplus/ultraman/app/purchaserinvoicemanagesaas/metadata/FormMeta.java <==
package com.xforceplus.ultraman.app.purchaserinvoicemanagesaas.metadata;

/**
 *
 * @author ultraman
 * @since 2025-03-12
 */

public class FormMeta {
    public interface BusinessField {
        static String code() {
            return "businessField";
        }
        static String name() {
            return "业务字段变更表单";
        }
    }
    public interface AddRiskInvoice {
        static String code() {
            return "addRiskInvoice";
        }
        static String name() {
            return "新增风险发票";
        }
    }
    public interface RiskInvoiceFollow {
        static String code() {
            return "riskInvoiceFollow";
        }
        static String name() {
            return "风险发票跟进";
        }
    }
    public interface VankeRiskInvoice {
        static String code() {
            return "vankeRiskInvoice";
        }
        static String name() {
            return "万科风险发票详情";
        }
    }
    public interface BizOrderDetailForm {
        static String code() {
            return "bizOrderDetailForm";
        }
        static String name() {
            return "发票池业务单详情";
        }
    }
    public interface DeleteImgDetail {
        static String code() {
            return "deleteImgDetail";
        }
        static String name() {
            return "已删除影像详情";
        }
    }
    public interface InvoicePoolButtonForm {
        static String code() {
            return "invoicePoolButtonForm";
        }
        static String name() {
            return "发票池 按钮 弹框表单";
        }
    }
    public interface InvoiceEntryStatusForm {
        static String code() {
            return "invoiceEntryStatusForm";
        }
        static String name() {
            return "发票入账调整入账未入账状态表单";
        }
    }
    public interface InvoiceEntryForm {
        static String code() {
            return "invoiceEntryForm";
        }
        static String name() {
            return "发票入账调整入账已入账、入账失败状态表单";
        }
    }
    public interface DownloadFile {
        static String code() {
            return "downloadFile";
        }
        static String name() {
            return "下载影像/文件";
        }
    }
    public interface InvoiceCheckedRollOutForm {
        static String code() {
            return "invoiceCheckedRollOutForm";
        }
        static String name() {
            return "发票已认证进转出弹窗表单";
        }
    }
}
